==> kwebkitpart-1.3.5-0.1.20170506git-src.tar.xz: kwebkitpart/src/ui/featurepermissionbar.h <==
/*
 * This file is part of the KDE project.
 *
 * Copyright (C) 2013 Allan Sandfeld Jensen <sandfeld @ kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef FEATUREPERMISSIONBAR_H
#define FEATUREPERMISSIONBAR_H

#include <KDE/KMessageWidget>

#include <QWebPage>


class FeaturePermissionBar : public KMessageWidget
{
    Q_OBJECT
public:
    explicit FeaturePermissionBar(QWidget *parent = 0);
    ~FeaturePermissionBar();

    QWebPage::Feature feature() const;

    void setFeature(QWebPage::Feature);

Q_SIGNALS:
    void permissionGranted(QWebPage::Feature);
    void permissionDenied(QWebPage::Feature);
    void done();

private Q_SLOTS:
    void onDeniedButtonClicked();
    void onGrantedButtonClicked();

private:
    QWebPage::Feature m_feature;
};

#endif // FEATUREPERMISSIONBAR_H

==> kwebkitpart-1.3.5-0.3.20180302git-src.tar.xz: kwebkitpart/src/ui/featurepermissionbar.h <==
/*
 * This file is part of the KDE project.
 *
 * Copyright (C) 2013 Allan Sandfeld Jensen <sandfeld @ kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef FEATUREPERMISSIONBAR_H
#define FEATUREPERMISSIONBAR_H

#include <KMessageWidget>

#include <QWebPage>


class FeaturePermissionBar : public KMessageWidget
{
    Q_OBJECT
public:
    explicit FeaturePermissionBar(QWidget *parent = 0);
    ~FeaturePermissionBar();

    QWebPage::Feature feature() const;

    void setFeature(QWebPage::Feature);

Q_SIGNALS:
    void permissionGranted(QWebPage::Feature);
    void permissionDenied(QWebPage::Feature);
    void done();

private Q_SLOTS:
    void onDeniedButtonClicked();
    void onGrantedButtonClicked();

private:
    QWebPage::Feature m_feature;
};

#endif // FEATUREPERMISSIONBAR_H
